@@ -310,7 +310,7 @@ void calcspline(splineptr thespline)
 /* Find the (x,y) position and tangent rotation of a point on a spline    */
 /*------------------------------------------------------------------------*/
 
-void findsplinepos(splineptr thespline, float t, XPoint *retpoint, int *retrot)
+void findsplinepos(splineptr thespline, float t, XPoint *retpoint, float *retrot)
 {
    float ax, bx, cx, ay, by, cy;
    float tsq = t * t;
@@ -324,7 +324,7 @@ void findsplinepos(splineptr thespline, float t, XPoint *retpoint, int *retrot)
    if (retrot != NULL) {
       dxdt = (double)(3 * ax * tsq + 2 * bx * t + cx);
       dydt = (double)(3 * ay * tsq + 2 * by * t + cy);
-      *retrot = (int)(INVRFAC * atan2(dxdt, dydt));  /* reversed y, x */
+      *retrot = INVRFAC * atan2(dxdt, dydt);  /* reversed y, x */
       if (*retrot < 0) *retrot += 360;
    }
 }
@@ -636,10 +636,10 @@ void user_to_window(XPoint upt, XPoint *wpt)
 /* Return rotation relative to a specific CTM				*/
 /*----------------------------------------------------------------------*/
 
-int UGetCTMRotation(Matrix *ctm)
+float UGetCTMRotation(Matrix *ctm)
 {
    float rads = (float)atan2((double)(ctm->d), (double)(ctm->a));
-   return (int)(rads / RADFAC);
+   return rads / RADFAC;
 }
 
 /*----------------------------------------------------------------------*/
@@ -649,7 +649,7 @@ int UGetCTMRotation(Matrix *ctm)
 /* window.  Thus, there is no routine UTopDrawingRotation().		*/
 /*----------------------------------------------------------------------*/
 
-int UTopRotation()
+float UTopRotation()
 {
    return UGetCTMRotation(DCTM);
 }
@@ -910,7 +910,7 @@ void UMakeWCTM(Matrix *ctm)
 
 /*------------------------------------------------------------------------*/
 
-void UMultCTM(Matrix *ctm, XPoint position, float scale, short rotate)
+void UMultCTM(Matrix *ctm, XPoint position, float scale, float rotate)
 {
    float tmpa, tmpb, tmpd, tmpe, yscale;
    float mata, matb, matc;
@@ -989,31 +989,39 @@ void UPreScaleCTM(Matrix *ctm)
 }
 
 /*----------------------------------------------------------------------*/
-/* Adjust justification and CTM as necessary for flip invariance	*/
+/* Adjust anchoring and CTM as necessary for flip invariance		*/
 /*----------------------------------------------------------------------*/
 
-short flipadjust(short justify)
+short flipadjust(short anchor)
 {
-   short tmpjust = justify & (~FLIPINV);
+   short tmpanchor = anchor & (~FLIPINV);
 
-   if (justify & FLIPINV) {
+   if (anchor & FLIPINV) {
       if (((DCTM)->a < -EPS) || (((DCTM)->a < EPS) && ((DCTM)->a > -EPS) &&
 		(((DCTM)->d * (DCTM)->b) < 0))) {
-         if ((tmpjust & (RIGHT | NOTLEFT)) != NOTLEFT)
-            tmpjust ^= (RIGHT | NOTLEFT);
+         if ((tmpanchor & (RIGHT | NOTLEFT)) != NOTLEFT)
+            tmpanchor ^= (RIGHT | NOTLEFT);
+
+	 /* Right justification of flipped text becomes left justification */
+	 /* and vice versa.						   */
+
+         if (tmpanchor & JUSTIFYRIGHT)
+            tmpanchor &= (~JUSTIFYRIGHT);
+         else if ((tmpanchor & (JUSTIFYBOTH | JUSTIFYRIGHT | TEXTCENTERED)) == 0)
+            tmpanchor |= (JUSTIFYRIGHT);
       }   
       if ((DCTM)->e > EPS) {
-         if ((tmpjust & (TOP | NOTBOTTOM)) != NOTBOTTOM) 
-            tmpjust ^= (TOP | NOTBOTTOM);
+         if ((tmpanchor & (TOP | NOTBOTTOM)) != NOTBOTTOM) 
+            tmpanchor ^= (TOP | NOTBOTTOM);
       }
       UPreScaleCTM(DCTM);
    }      
-   return tmpjust;
+   return tmpanchor;
 }
 
 /*------------------------------------------------------------------------*/
 
-void UPreMultCTM(Matrix *ctm, XPoint position, float scale, short rotate)
+void UPreMultCTM(Matrix *ctm, XPoint position, float scale, float rotate)
 {
    float tmpa, tmpb, tmpd, tmpe, yscale;
    float mata, matd;
@@ -1141,7 +1149,7 @@ void UPushCTM()
 /*------------------------------------------------------------------------*/
 
 void UTransformPoints(XPoint *points, XPoint *newpoints, short number,
-	XPoint atpt, float scale, short rotate)
+	XPoint atpt, float scale, float rotate)
 {
    Matrix LCTM;
  
@@ -1155,7 +1163,7 @@ void UTransformPoints(XPoint *points, XPoint *newpoints, short number,
 /*----------------------------------------------------*/
 
 void InvTransformPoints(XPoint *points, XPoint *newpoints, short number,
-	XPoint atpt, float scale, short rotate)
+	XPoint atpt, float scale, float rotate)
 {
    Matrix LCTM;
  
@@ -1337,13 +1345,13 @@ void labelbbox(labelptr labox, XPoint *npoints, objinstptr callinst)
    TextExtents tmpext;
    short j;
 
-   tmpext = ULength(labox, callinst, 0, NULL);
-   points[0].x = points[1].x = (labox->justify & NOTLEFT ? 
-	       (labox->justify & RIGHT ? -tmpext.maxwidth :
+   tmpext = ULength(labox, callinst, NULL);
+   points[0].x = points[1].x = (labox->anchor & NOTLEFT ? 
+	       (labox->anchor & RIGHT ? -tmpext.maxwidth :
 		-tmpext.maxwidth / 2) : 0);
    points[2].x = points[3].x = points[0].x + tmpext.maxwidth;
-   points[0].y = points[3].y = (labox->justify & NOTBOTTOM ?
-	       (labox->justify & TOP ? -tmpext.ascent :
+   points[0].y = points[3].y = (labox->anchor & NOTBOTTOM ?
+	       (labox->anchor & TOP ? -tmpext.ascent :
 		-(tmpext.ascent + tmpext.base) / 2) : -tmpext.base)
 		+ tmpext.descent;
    points[1].y = points[2].y = points[0].y + tmpext.ascent - tmpext.descent;
@@ -1352,7 +1360,7 @@ void labelbbox(labelptr labox, XPoint *npoints, objinstptr callinst)
 
    if (labox->pin)
       for (j = 0; j < 4; j++)
-	 pinadjust(labox->justify, &points[j].x, &points[j].y, 1);
+	 pinadjust(labox->anchor, &points[j].x, &points[j].y, 1);
 
    UTransformPoints(points, npoints, 4, labox->position,
 		labox->scale, labox->rotation); 
@@ -1570,7 +1578,7 @@ void calcbboxinst(objinstptr thisinst)
 
       if (IS_LABEL(*gelem)) {
 	 labelptr btext = TOLABEL(gelem);
-	 if (btext->pin && !(btext->justify & PINVISIBLE)) {
+	 if (btext->pin && !(btext->anchor & PINVISIBLE)) {
 	    hasschembbox = TRUE;
 	    calcbboxsingle(gelem, thisinst, &pllx, &plly, &purx, &pury);
 	    continue;
@@ -1729,7 +1737,7 @@ void calcbboxvalues(objinstptr thisinst, genericptr *newelement)
 
 	 if (IS_LABEL(*bboxgen)) {
 	    labelptr btext = TOLABEL(bboxgen);
-	    if (btext->pin && !(btext->justify & PINVISIBLE)) {
+	    if (btext->pin && !(btext->anchor & PINVISIBLE)) {
 	       goto nextgen;
 	    }
 	 }
@@ -1816,7 +1824,7 @@ void centerview(objinstptr tinst)
 
    /* Copy new position values to the current window */
 
-   if (tobj == topobject) {
+   if ((areawin->topinstance != NULL) && (tobj == topobject)) {
       areawin->pcorner = tobj->pcorner;
       areawin->vscale = tobj->viewscale;
    }
@@ -1848,7 +1856,8 @@ void zoomview(xcWidget w, caddr_t clientdata, caddr_t calldata)
 	eventmode == FONTCAT_MODE || eventmode == EFONTCAT_MODE ||
 	eventmode == CATMOVE_MODE) {
 
-      centerview(areawin->topinstance);
+      if (areawin->topinstance)
+	 centerview(areawin->topinstance);
       areawin->lastbackground = NULL;
       renderbackground();
       refresh(NULL, NULL, NULL);
@@ -2065,14 +2074,14 @@ void extendschembbox(objinstptr bbinst, XPoint *origin, XPoint *corner)
 /* Adjust a pinlabel position to account for pad spacing		*/
 /*----------------------------------------------------------------------*/
 
-void pinadjust (short justify, short *xpoint, short *ypoint, short dir)
+void pinadjust (short anchor, short *xpoint, short *ypoint, short dir)
 {
    int delx, dely;
 
-   dely = (justify & NOTBOTTOM) ?
-            ((justify & TOP) ? -PADSPACE : 0) : PADSPACE;
-   delx = (justify & NOTLEFT) ?
-            ((justify & RIGHT) ? -PADSPACE : 0) : PADSPACE;
+   dely = (anchor & NOTBOTTOM) ?
+            ((anchor & TOP) ? -PADSPACE : 0) : PADSPACE;
+   delx = (anchor & NOTLEFT) ?
+            ((anchor & RIGHT) ? -PADSPACE : 0) : PADSPACE;
 
    if (xpoint != NULL) *xpoint += (dir > 0) ? delx : -delx;
    if (ypoint != NULL) *ypoint += (dir > 0) ? dely : -dely;
@@ -2086,8 +2095,10 @@ void pinadjust (short justify, short *xpoint, short *ypoint, short dir)
 void UDrawTextLine(labelptr curlabel, short tpos)
 {
    XPoint  points[2]; /* top and bottom of text cursor line */
-   short   xdist, xbase, tmpjust;
+   short   tmpanchor, xbase;
+   int     maxwidth;
    TextExtents tmpext;
+   TextLinesInfo tlinfo;
    
    if (!areawin->redraw_ongoing) {
       areawin->redraw_needed = True;
@@ -2098,28 +2109,37 @@ void UDrawTextLine(labelptr curlabel, short tpos)
 
    UPushCTM();
    UPreMultCTM(DCTM, curlabel->position, curlabel->scale, curlabel->rotation);
-   tmpjust = flipadjust(curlabel->justify);
+   tmpanchor = flipadjust(curlabel->anchor);
 
    SetForeground(dpy, areawin->gc, AUXCOLOR);
 
-   tmpext = ULength(curlabel, areawin->topinstance, tpos, NULL);
-   xdist = tmpext.width;
-   xbase = tmpext.base;
-   tmpext = ULength(curlabel, areawin->topinstance, 0, NULL);
+   tlinfo.dostop = 0;
+   tlinfo.tbreak = NULL;
+   tlinfo.padding = NULL;
 
-   points[0].x = (tmpjust & NOTLEFT ?
-        (tmpjust & RIGHT ? -tmpext.maxwidth : -tmpext.maxwidth >> 1) : 0)
-	+ xdist;
-   points[0].y = (tmpjust & NOTBOTTOM ?
-        (tmpjust & TOP ? -tmpext.ascent : -(tmpext.ascent + tmpext.base) / 2)
-	: -tmpext.base) + xbase - 3;
+   tmpext = ULength(curlabel, areawin->topinstance, &tlinfo);
+   maxwidth = tmpext.maxwidth;
+   xbase = tmpext.base;
+   tlinfo.dostop = tpos;
+   tmpext = ULength(curlabel, areawin->topinstance, &tlinfo);
+
+   points[0].x = (tmpanchor & NOTLEFT ?
+        (tmpanchor & RIGHT ? -maxwidth : -maxwidth >> 1) : 0) + tmpext.width;
+   if (tmpanchor & JUSTIFYRIGHT)
+      points[0].x += tlinfo.padding[tlinfo.line];
+   else if (tmpanchor & TEXTCENTERED)
+      points[0].x += 0.5 * tlinfo.padding[tlinfo.line];
+   points[0].y = (tmpanchor & NOTBOTTOM ?
+        (tmpanchor & TOP ? -tmpext.ascent : -(tmpext.ascent + xbase) / 2)
+	: -xbase) + tmpext.base - 3;
    points[1].x = points[0].x;
    points[1].y = points[0].y + TEXTHEIGHT + 6;
 
    if (curlabel->pin) {
-      pinadjust(tmpjust, &(points[0].x), &(points[0].y), 1);
-      pinadjust(tmpjust, &(points[1].x), &(points[1].y), 1);
+      pinadjust(tmpanchor, &(points[0].x), &(points[0].y), 1);
+      pinadjust(tmpanchor, &(points[1].x), &(points[1].y), 1);
    }
+   if (tlinfo.padding != NULL) free(tlinfo.padding);
 
    /* draw the line */
 
@@ -2765,9 +2785,9 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor,
   	  case(LABEL): 
 	     if (level == 0 || TOLABEL(areagen)->pin == False)
                 UDrawString(TOLABEL(areagen), curcolor, theinstance);
-	     else if ((TOLABEL(areagen)->justify & PINVISIBLE) && areawin->pinpointon)
+	     else if ((TOLABEL(areagen)->anchor & PINVISIBLE) && areawin->pinpointon)
                 UDrawString(TOLABEL(areagen), curcolor, theinstance);
-	     else if (TOLABEL(areagen)->justify & PINVISIBLE)
+	     else if (TOLABEL(areagen)->anchor & PINVISIBLE)
                 UDrawStringNoX(TOLABEL(areagen), curcolor, theinstance);
 	     else if (level == 1 && TOLABEL(areagen)->pin &&
 			TOLABEL(areagen)->pin != INFO && areawin->pinpointon)
@@ -2845,7 +2865,7 @@ void UDoLatex(objinstptr theinstance, short level, FILE *f,
    genericptr	*areagen;
    objectptr	theobject = theinstance->thisobject;
    char		*ltext;
-   int		lrjust, tbjust;
+   int		lranchor, tbanchor;
 
    UPushCTM();
    if (level != 0)
@@ -2868,8 +2888,8 @@ void UDoLatex(objinstptr theinstance, short level, FILE *f,
 	 case(LABEL): 
 	    thislabel = TOLABEL(areagen);
 	    if (level == 0 || thislabel->pin == False ||
-			(thislabel->justify & PINVISIBLE))
-		if (thislabel->justify & LATEXLABEL) {
+			(thislabel->anchor & PINVISIBLE))
+		if (thislabel->anchor & LATEXLABEL) {
 		    if (checkonly) {
 		       *checkonly = TRUE;
 		       return;
@@ -2891,8 +2911,8 @@ void UDoLatex(objinstptr theinstance, short level, FILE *f,
 		       xfpos.x /= scale2;
 		       xfpos.y /= scale2;
 		       ltext = textprinttex(thislabel->string, theinstance);
-		       tbjust = thislabel->justify & (NOTBOTTOM | TOP);
-		       lrjust = thislabel->justify & (NOTLEFT | RIGHT);
+		       tbanchor = thislabel->anchor & (NOTBOTTOM | TOP);
+		       lranchor = thislabel->anchor & (NOTLEFT | RIGHT);
 
 		       /* The 1.2 factor accounts for the difference between	 */
 		       /* Xcircuit's label scale of "1" and LaTeX's "normalsize" */
@@ -2901,13 +2921,13 @@ void UDoLatex(objinstptr theinstance, short level, FILE *f,
 				xfpos.x, xfpos.y, 1.2 * thislabel->scale);
 		       if (thislabel->rotation != 0)
 			  fprintf(f, "\\rotatebox{-%d}{", thislabel->rotation);
-		       if (lrjust == (NOTLEFT | RIGHT)) fprintf(f, "\\rightbox{");
-		       else if (lrjust == NOTLEFT) fprintf(f, "\\centbox{");
-		       if (tbjust == (NOTBOTTOM | TOP)) fprintf(f, "\\topbox{");
-		       else if (tbjust == NOTBOTTOM) fprintf(f, "\\midbox{");
+		       if (lranchor == (NOTLEFT | RIGHT)) fprintf(f, "\\rightbox{");
+		       else if (lranchor == NOTLEFT) fprintf(f, "\\centbox{");
+		       if (tbanchor == (NOTBOTTOM | TOP)) fprintf(f, "\\topbox{");
+		       else if (tbanchor == NOTBOTTOM) fprintf(f, "\\midbox{");
 		       fprintf(f, "%s", ltext);
-		       if (lrjust != NORMAL) fprintf(f, "}");
-		       if (tbjust != NORMAL) fprintf(f, "}");
+		       if (lranchor != NORMAL) fprintf(f, "}");
+		       if (tbanchor != NORMAL) fprintf(f, "}");
 		       if (thislabel->rotation != 0) fprintf(f, "}");
 		       fprintf(f, "}%%\n");
 		       free(ltext);
