@@ -131,7 +131,7 @@ void printhelppix()
     { XCF_Dotted,	"Dotted line style"},
     { XCF_Solid,	"Solid line style"},
     { XCF_SPACER,	NULL},
-    { XCF_Justify,	"Text Justification"},
+    { XCF_Anchor,	"Text Anchoring"},
     { XCF_Superscript,	"Text Superscript"},
     { XCF_Subscript,	"Text Subscript"},
     { XCF_Font,		"Toggle text font"},
