@@ -49,7 +49,7 @@ keybinding *keylist = NULL;
 
 extern Display *dpy;
 extern char  _STR[150], _STR2[250];
-extern Boolean pressmode;
+extern int pressmode;
 extern XCWindowData *areawin;
 
 /*----------------------------------------------------------------------*/
@@ -81,7 +81,7 @@ extern XCWindowData *areawin;
 /*--------------------------------------------------------------*/
 
 static char *function_names[NUM_FUNCTIONS + 1] = {
-   "Page", "Justify", "Superscript", "Subscript", "Normalscript",
+   "Page", "Anchor", "Superscript", "Subscript", "Normalscript",
    "Nextfont", "Boldfont", "Italicfont", "Normalfont", "Underline",
    "Overline", "ISO Encoding", "Halfspace", "Quarterspace",
    "Special", "Tab Stop", "Tab Forward", "Tab Backward",
@@ -103,7 +103,8 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Netlist", "Swap", "Pin Label", "Pin Global", "Info Label", "Graphic",
    "Select Box", "Connectivity", "Continue Element", "Finish Element",
    "Continue Copy", "Finish Copy", "Finish", "Cancel Last", "Sim",
-   "SPICE", "PCB", "SPICE Flat", "Rescale", "Text Delete Param",
+   "SPICE", "PCB", "SPICE Flat", "Rescale", "Reorder", "Color",
+   "Margin Stop", "Text Delete Param",
    NULL			/* sentinel */
 };
 
@@ -619,25 +620,25 @@ void default_keybindings()
    add_vbinding(ALL_WINDOWS, XK_9, XCF_Page, 9);
    add_vbinding(ALL_WINDOWS, XK_0, XCF_Page, 10);
 
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_1, XCF_Justify, 0);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_2, XCF_Justify, 1);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_3, XCF_Justify, 2);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_4, XCF_Justify, 3);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_5, XCF_Justify, 4);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_6, XCF_Justify, 5);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_7, XCF_Justify, 6);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_8, XCF_Justify, 7);
-   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_9, XCF_Justify, 8);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_1, XCF_Anchor, 0);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_2, XCF_Anchor, 1);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_3, XCF_Anchor, 2);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_4, XCF_Anchor, 3);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_5, XCF_Anchor, 4);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_6, XCF_Anchor, 5);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_7, XCF_Anchor, 6);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_8, XCF_Anchor, 7);
+   add_vbinding(ALL_WINDOWS, SHIFT | XK_KP_9, XCF_Anchor, 8);
 
-   add_vbinding(ALL_WINDOWS, XK_KP_End, XCF_Justify, 0);
-   add_vbinding(ALL_WINDOWS, XK_KP_Down, XCF_Justify, 1);
-   add_vbinding(ALL_WINDOWS, XK_KP_Next, XCF_Justify, 2);
-   add_vbinding(ALL_WINDOWS, XK_KP_Left, XCF_Justify, 3);
-   add_vbinding(ALL_WINDOWS, XK_KP_Begin, XCF_Justify, 4);
-   add_vbinding(ALL_WINDOWS, XK_KP_Right, XCF_Justify, 5);
-   add_vbinding(ALL_WINDOWS, XK_KP_Home, XCF_Justify, 6);
-   add_vbinding(ALL_WINDOWS, XK_KP_Up, XCF_Justify, 7);
-   add_vbinding(ALL_WINDOWS, XK_KP_Prior, XCF_Justify, 8);
+   add_vbinding(ALL_WINDOWS, XK_KP_End, XCF_Anchor, 0);
+   add_vbinding(ALL_WINDOWS, XK_KP_Down, XCF_Anchor, 1);
+   add_vbinding(ALL_WINDOWS, XK_KP_Next, XCF_Anchor, 2);
+   add_vbinding(ALL_WINDOWS, XK_KP_Left, XCF_Anchor, 3);
+   add_vbinding(ALL_WINDOWS, XK_KP_Begin, XCF_Anchor, 4);
+   add_vbinding(ALL_WINDOWS, XK_KP_Right, XCF_Anchor, 5);
+   add_vbinding(ALL_WINDOWS, XK_KP_Home, XCF_Anchor, 6);
+   add_vbinding(ALL_WINDOWS, XK_KP_Up, XCF_Anchor, 7);
+   add_vbinding(ALL_WINDOWS, XK_KP_Prior, XCF_Anchor, 8);
 
    add_binding(ALL_WINDOWS, XK_Delete, XCF_Text_Delete);
    add_binding(ALL_WINDOWS, XK_Return, XCF_Text_Return);
@@ -779,7 +780,7 @@ void default_keybindings()
    /* 2-button vs. 3-button mouse bindings (set with -2	*/
    /* commandline option; 3-button bindings default)	*/
 
-   if (pressmode) {
+   if (pressmode == 1) {
       add_binding(ALL_WINDOWS, BUTTON3, XCF_Text_Return);
       add_binding(ALL_WINDOWS, BUTTON3, XCF_Select);
       add_binding(ALL_WINDOWS, HOLD | BUTTON3, XCF_SelectBox);
