@@ -648,7 +648,7 @@ void composepagelib(short mode)
 	 strptr->type = TEXT_STRING;
 	 strptr->data.string = (char *) malloc(1 + strlen(libobj->name));
 	 strcpy(strptr->data.string, libobj->name);
-	 (*pagelabel)->justify = TOP | NOTBOTTOM | NOTLEFT;
+	 (*pagelabel)->anchor = TOP | NOTBOTTOM | NOTLEFT;
       }
    }
 
@@ -895,14 +895,14 @@ void composelib(short mode)
 	 strptr->type = TEXT_STRING;
 
          strptr->data.string = strdup(libobj->name);
-         (*drawname)->justify = TOP | NOTBOTTOM | NOTLEFT;
+         (*drawname)->anchor = TOP | NOTBOTTOM | NOTLEFT;
 
 	 /* If the label is longer than the object width, then	*/
 	 /* adjust positions accordingly.  Note that as an ad-	*/
 	 /* hoc spacing rule, a padding of 30 is put between	*/
 	 /* objects; this padding is reduced to 5 		*/
 
-	 tmpext = ULength(*drawname, drawinst, 0, NULL);
+	 tmpext = ULength(*drawname, drawinst, NULL);
 
 	 /* Ad-hoc spacing rule is 5 for labels */
 	 tmpext.width += 5;
