@@ -76,14 +76,14 @@ menustruct TextSpacing[] = {
 	{"Character", action(addtotext, Number(SPECIAL))},
 };
 
-menustruct Justifs[] = {
-	{"Left Justified", setaction(sethjust, Number(NORMAL))},
-	{"Center Justified", action(sethjust, Number(NOTLEFT))},
-	{"Right Justified", action(sethjust, Number(NOTLEFT | RIGHT))},
+menustruct Anchors[] = {
+	{"Left Anchored", setaction(sethjust, Number(NORMAL))},
+	{"Center Anchored", action(sethjust, Number(NOTLEFT))},
+	{"Right Anchored", action(sethjust, Number(NOTLEFT | RIGHT))},
 	{" ", noaction},
-	{"Top Justified", action(setvjust, Number(NOTBOTTOM | TOP))},
-	{"Middle Justified", action(setvjust, Number(NOTBOTTOM))},
-	{"Bottom Justified", setaction(setvjust, Number(NORMAL))},
+	{"Top Anchored", action(setvjust, Number(NOTBOTTOM | TOP))},
+	{"Middle Anchored", action(setvjust, Number(NOTBOTTOM))},
+	{"Bottom Anchored", setaction(setvjust, Number(NORMAL))},
 	{" ", noaction},
 	{"Flip Invariant", setaction(setjustbit, Number(FLIPINV))},
 };
@@ -150,7 +150,7 @@ menustruct Parameterize[] = {
 	{"Substring", action(promptparam, NULL)},
 	{"Numeric", action(startparam, Number(P_NUMERIC))},
 	{"Style", action(startparam, Number(P_STYLE))},
-	{"Justification", action(startparam, Number(P_JUSTIFY))},
+	{"Anchoring", action(startparam, Number(P_ANCHOR))},
 	{"Start Angle", action(startparam, Number(P_ANGLE1))},
 	{"End Angle", action(startparam, Number(P_ANGLE2))},
 	{"Radius", action(startparam, Number(P_RADIUS))},
@@ -183,7 +183,7 @@ menustruct TextMenu[] = {
 	{"Style", submenu(FontStyles)},
 	{"Encoding", submenu(FontEncodings)},
 	{"Insert", submenu(TextSpacing)},             
-	{"Justification (keypad)", submenu(Justifs)},
+	{"Anchoring (keypad)", submenu(Anchors)},
 	{"Parameterize", action(promptparam, NULL)},
 	{"Unparameterize", action(startunparam, Number(P_SUBSTRING))},
 	{" ", noaction},
