@@ -80,7 +80,7 @@ extern void textbutton(u_char, int, int);
 extern void charreport(labelptr);
 extern Boolean labeltext(int, char *);
 extern void textreturn(void);
-extern void rejustify(short);
+extern void reanchor(short);
 extern void findconstrained(polyptr);
 extern void reversepoints(XPoint *, short);
 extern void reversefpoints(XfPoint *, short);
@@ -165,14 +165,14 @@ extern int ipow10(int);
 extern int calcgcf(int, int);
 extern void fraccalc(float, char *);
 extern void printpos(short, short);
-extern void findwirex(XPoint *, XPoint *, XPoint *, XPoint *, int *);
-extern void findattach(XPoint *, int *, XPoint *);
+extern void findwirex(XPoint *, XPoint *, XPoint *, XPoint *, float *);
+extern void findattach(XPoint *, float *, XPoint *);
 extern XPoint *pathclosepoint(pathptr, XPoint *);
 extern void placeselects(short, short, XPoint *);
 extern void drag(int, int);
 extern void xlib_drag(xcWidget, caddr_t, XEvent *);
-extern void elemrotate(genericptr *, short, XPoint *);
-extern void elementrotate(short, XPoint *);
+extern void elemrotate(genericptr *, float, XPoint *);
+extern void elementrotate(float, XPoint *);
 extern void edit(int, int);
 extern void pathedit(genericptr);
 extern void xc_lower();
@@ -368,7 +368,7 @@ extern void initsplines(void);
 extern void computecoeffs(splineptr, float *, float *, float *, float *,
                           float *, float *);
 extern void calcspline(splineptr);
-extern void findsplinepos(splineptr, float, XPoint *, int *);
+extern void findsplinepos(splineptr, float, XPoint *, float *);
 extern void ffindsplinepos(splineptr, float, XfPoint *);
 extern float findsplinemin(splineptr, XPoint *);
 extern short closepoint(polyptr, XPoint *);
@@ -381,7 +381,7 @@ extern void user_to_window(XPoint, XPoint *);
 extern float UTopScale(void);
 extern float UTopTransScale(float);
 extern float UTopDrawingScale(void);
-extern int UTopRotation(void);
+extern float UTopRotation(void);
 extern void UTopOffset(int *, int *);
 extern void UTopDrawingOffset(int *, int *);
 
@@ -393,20 +393,20 @@ extern void UResetCTM(Matrix *);
 extern void InvertCTM(Matrix *);
 extern void UCopyCTM(Matrix *, Matrix *);
 extern void UMakeWCTM(Matrix *);
-extern void UMultCTM(Matrix *, XPoint, float, short);
+extern void UMultCTM(Matrix *, XPoint, float, float);
 extern void USlantCTM(Matrix *, float);
 extern void UPreScaleCTM(Matrix *);
 extern short flipadjust(short);
-extern void UPreMultCTM(Matrix *, XPoint, float, short);
+extern void UPreMultCTM(Matrix *, XPoint, float, float);
 extern void UPreMultCTMbyMat(Matrix *, Matrix *);
 extern void UTransformbyCTM(Matrix *, XPoint *, XPoint *, short);
 extern void UfTransformbyCTM(Matrix *, XfPoint *, XPoint *, short);
 extern void UPopCTM(void);
 extern void UPushCTM(void);
 extern void UTransformPoints(XPoint *, XPoint *, short, XPoint, float,
-                             short);
+                             float);
 extern void InvTransformPoints(XPoint *, XPoint *, short, XPoint, float,
-                             short);
+                             float);
 extern void manhattanize(XPoint *, polyptr, short, Boolean);
 extern void bboxcalc(short, short *, short *);
 extern void calcextents(genericptr *, short *, short *, short *, short *);
@@ -557,11 +557,11 @@ extern void setfontmarks(short, short);
 extern void startparam(xcWidget, pointertype, caddr_t);
 extern void startunparam(xcWidget, pointertype, caddr_t);
 extern void setdefaultfontmarks(void);
-extern void setjustbit(xcWidget, pointertype, caddr_t);
-extern void setpinjustbit(xcWidget, pointertype, caddr_t);
-extern void setjust(xcWidget, pointertype, labelptr, short);
-extern void setvjust(xcWidget, pointertype, caddr_t);
-extern void sethjust(xcWidget, pointertype, caddr_t);
+extern void setanchorbit(xcWidget, pointertype, caddr_t);
+extern void setpinanchorbit(xcWidget, pointertype, caddr_t);
+extern void setanchor(xcWidget, pointertype, labelptr, short);
+extern void setvanchor(xcWidget, pointertype, caddr_t);
+extern void sethanchor(xcWidget, pointertype, caddr_t);
 extern void boxedit(xcWidget, pointertype, caddr_t);
 extern void locloadfont(xcWidget, char *);
 extern short findbestfont(short, short, short, short);
@@ -582,7 +582,7 @@ extern void setfloat(xcWidget, float *);
 extern void autoset(xcWidget, xcWidgetList, caddr_t);
 extern void autostop(xcWidget, caddr_t, caddr_t);
 extern void togglegridstyles(xcWidget);
-extern void togglejustifs(xcWidget);
+extern void toggleanchors(xcWidget);
 extern void togglefontstyles(xcWidget);
 extern void toggleencodings(xcWidget);
 extern void getkern(xcWidget, caddr_t, caddr_t);
@@ -977,7 +977,7 @@ void UDrawCharString(u_char *text, int start, int end, XfPoint *offset,
 extern void UDrawString(labelptr, int, objinstptr);
 extern void UDrawStringNoX(labelptr, int, objinstptr);
 extern void CheckMarginStop(labelptr, objinstptr, Boolean);
-extern TextExtents ULength(labelptr, objinstptr, short, XPoint *);
+extern TextExtents ULength(labelptr, objinstptr, TextLinesInfo *);
 extern void undrawtext(labelptr);
 extern void redrawtext(labelptr);
 extern void composefontlib(short);
